# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/endpoint/serializers.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/datatransfer/v1/endpoint/serializers.proto',
  package='yandex.cloud.datatransfer.v1.endpoint',
  syntax='proto3',
  serialized_options=b'\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\252\002%Yandex.Cloud.Datatransfer.V1.EndPoint',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7yandex/cloud/datatransfer/v1/endpoint/serializers.proto\x12%yandex.cloud.datatransfer.v1.endpoint\"\x10\n\x0eSerializerAuto\"\x10\n\x0eSerializerJSON\"9\n\x1b\x44\x65\x62\x65ziumSerializerParameter\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"w\n\x12SerializerDebezium\x12\x61\n\x15serializer_parameters\x18\x01 \x03(\x0b\x32\x42.yandex.cloud.datatransfer.v1.endpoint.DebeziumSerializerParameter\"\x98\x02\n\nSerializer\x12P\n\x0fserializer_auto\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.datatransfer.v1.endpoint.SerializerAutoH\x00\x12P\n\x0fserializer_json\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.datatransfer.v1.endpoint.SerializerJSONH\x00\x12X\n\x13serializer_debezium\x18\x03 \x01(\x0b\x32\x39.yandex.cloud.datatransfer.v1.endpoint.SerializerDebeziumH\x00\x42\x0c\n\nserializerB\xa7\x01\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\xaa\x02%Yandex.Cloud.Datatransfer.V1.EndPointb\x06proto3'
)




_SERIALIZERAUTO = _descriptor.Descriptor(
  name='SerializerAuto',
  full_name='yandex.cloud.datatransfer.v1.endpoint.SerializerAuto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=114,
)


_SERIALIZERJSON = _descriptor.Descriptor(
  name='SerializerJSON',
  full_name='yandex.cloud.datatransfer.v1.endpoint.SerializerJSON',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=132,
)


_DEBEZIUMSERIALIZERPARAMETER = _descriptor.Descriptor(
  name='DebeziumSerializerParameter',
  full_name='yandex.cloud.datatransfer.v1.endpoint.DebeziumSerializerParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.datatransfer.v1.endpoint.DebeziumSerializerParameter.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.datatransfer.v1.endpoint.DebeziumSerializerParameter.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=191,
)


_SERIALIZERDEBEZIUM = _descriptor.Descriptor(
  name='SerializerDebezium',
  full_name='yandex.cloud.datatransfer.v1.endpoint.SerializerDebezium',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serializer_parameters', full_name='yandex.cloud.datatransfer.v1.endpoint.SerializerDebezium.serializer_parameters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=193,
  serialized_end=312,
)


_SERIALIZER = _descriptor.Descriptor(
  name='Serializer',
  full_name='yandex.cloud.datatransfer.v1.endpoint.Serializer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serializer_auto', full_name='yandex.cloud.datatransfer.v1.endpoint.Serializer.serializer_auto', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serializer_json', full_name='yandex.cloud.datatransfer.v1.endpoint.Serializer.serializer_json', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serializer_debezium', full_name='yandex.cloud.datatransfer.v1.endpoint.Serializer.serializer_debezium', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='serializer', full_name='yandex.cloud.datatransfer.v1.endpoint.Serializer.serializer',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=315,
  serialized_end=595,
)

_SERIALIZERDEBEZIUM.fields_by_name['serializer_parameters'].message_type = _DEBEZIUMSERIALIZERPARAMETER
_SERIALIZER.fields_by_name['serializer_auto'].message_type = _SERIALIZERAUTO
_SERIALIZER.fields_by_name['serializer_json'].message_type = _SERIALIZERJSON
_SERIALIZER.fields_by_name['serializer_debezium'].message_type = _SERIALIZERDEBEZIUM
_SERIALIZER.oneofs_by_name['serializer'].fields.append(
  _SERIALIZER.fields_by_name['serializer_auto'])
_SERIALIZER.fields_by_name['serializer_auto'].containing_oneof = _SERIALIZER.oneofs_by_name['serializer']
_SERIALIZER.oneofs_by_name['serializer'].fields.append(
  _SERIALIZER.fields_by_name['serializer_json'])
_SERIALIZER.fields_by_name['serializer_json'].containing_oneof = _SERIALIZER.oneofs_by_name['serializer']
_SERIALIZER.oneofs_by_name['serializer'].fields.append(
  _SERIALIZER.fields_by_name['serializer_debezium'])
_SERIALIZER.fields_by_name['serializer_debezium'].containing_oneof = _SERIALIZER.oneofs_by_name['serializer']
DESCRIPTOR.message_types_by_name['SerializerAuto'] = _SERIALIZERAUTO
DESCRIPTOR.message_types_by_name['SerializerJSON'] = _SERIALIZERJSON
DESCRIPTOR.message_types_by_name['DebeziumSerializerParameter'] = _DEBEZIUMSERIALIZERPARAMETER
DESCRIPTOR.message_types_by_name['SerializerDebezium'] = _SERIALIZERDEBEZIUM
DESCRIPTOR.message_types_by_name['Serializer'] = _SERIALIZER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SerializerAuto = _reflection.GeneratedProtocolMessageType('SerializerAuto', (_message.Message,), {
  'DESCRIPTOR' : _SERIALIZERAUTO,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.serializers_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.SerializerAuto)
  })
_sym_db.RegisterMessage(SerializerAuto)

SerializerJSON = _reflection.GeneratedProtocolMessageType('SerializerJSON', (_message.Message,), {
  'DESCRIPTOR' : _SERIALIZERJSON,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.serializers_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.SerializerJSON)
  })
_sym_db.RegisterMessage(SerializerJSON)

DebeziumSerializerParameter = _reflection.GeneratedProtocolMessageType('DebeziumSerializerParameter', (_message.Message,), {
  'DESCRIPTOR' : _DEBEZIUMSERIALIZERPARAMETER,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.serializers_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.DebeziumSerializerParameter)
  })
_sym_db.RegisterMessage(DebeziumSerializerParameter)

SerializerDebezium = _reflection.GeneratedProtocolMessageType('SerializerDebezium', (_message.Message,), {
  'DESCRIPTOR' : _SERIALIZERDEBEZIUM,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.serializers_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.SerializerDebezium)
  })
_sym_db.RegisterMessage(SerializerDebezium)

Serializer = _reflection.GeneratedProtocolMessageType('Serializer', (_message.Message,), {
  'DESCRIPTOR' : _SERIALIZER,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.serializers_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.Serializer)
  })
_sym_db.RegisterMessage(Serializer)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/apigateway/websocket/v1/connection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/serverless/apigateway/websocket/v1/connection.proto',
  package='yandex.cloud.serverless.apigateway.websocket.v1',
  syntax='proto3',
  serialized_options=b'\n3yandex.cloud.api.serverless.apigateway.websocket.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/serverless/apigateway/websocket/v1;websocket',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n@yandex/cloud/serverless/apigateway/websocket/v1/connection.proto\x12/yandex.cloud.serverless.apigateway.websocket.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xdf\x01\n\nConnection\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ngateway_id\x18\x02 \x01(\t\x12K\n\x08identity\x18\x03 \x01(\x0b\x32\x39.yandex.cloud.serverless.apigateway.websocket.v1.Identity\x12\x30\n\x0c\x63onnected_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0elast_active_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"1\n\x08Identity\x12\x11\n\tsource_ip\x18\x01 \x01(\t\x12\x12\n\nuser_agent\x18\x02 \x01(\tB\x94\x01\n3yandex.cloud.api.serverless.apigateway.websocket.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/serverless/apigateway/websocket/v1;websocketb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_CONNECTION = _descriptor.Descriptor(
  name='Connection',
  full_name='yandex.cloud.serverless.apigateway.websocket.v1.Connection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.serverless.apigateway.websocket.v1.Connection.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gateway_id', full_name='yandex.cloud.serverless.apigateway.websocket.v1.Connection.gateway_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identity', full_name='yandex.cloud.serverless.apigateway.websocket.v1.Connection.identity', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connected_at', full_name='yandex.cloud.serverless.apigateway.websocket.v1.Connection.connected_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_active_at', full_name='yandex.cloud.serverless.apigateway.websocket.v1.Connection.last_active_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=374,
)


_IDENTITY = _descriptor.Descriptor(
  name='Identity',
  full_name='yandex.cloud.serverless.apigateway.websocket.v1.Identity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_ip', full_name='yandex.cloud.serverless.apigateway.websocket.v1.Identity.source_ip', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_agent', full_name='yandex.cloud.serverless.apigateway.websocket.v1.Identity.user_agent', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=376,
  serialized_end=425,
)

_CONNECTION.fields_by_name['identity'].message_type = _IDENTITY
_CONNECTION.fields_by_name['connected_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CONNECTION.fields_by_name['last_active_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['Connection'] = _CONNECTION
DESCRIPTOR.message_types_by_name['Identity'] = _IDENTITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Connection = _reflection.GeneratedProtocolMessageType('Connection', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTION,
  '__module__' : 'yandex.cloud.serverless.apigateway.websocket.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.apigateway.websocket.v1.Connection)
  })
_sym_db.RegisterMessage(Connection)

Identity = _reflection.GeneratedProtocolMessageType('Identity', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITY,
  '__module__' : 'yandex.cloud.serverless.apigateway.websocket.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.apigateway.websocket.v1.Identity)
  })
_sym_db.RegisterMessage(Identity)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ydb/v1/location_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.ydb.v1 import location_pb2 as yandex_dot_cloud_dot_ydb_dot_v1_dot_location__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/ydb/v1/location_service.proto',
  package='yandex.cloud.ydb.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*yandex/cloud/ydb/v1/location_service.proto\x12\x13yandex.cloud.ydb.v1\x1a\x1cgoogle/api/annotations.proto\x1a\"yandex/cloud/ydb/v1/location.proto\x1a\x1dyandex/cloud/validation.proto\"/\n\x12GetLocationRequest\x12\x19\n\x0blocation_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"T\n\x14ListLocationsRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\"b\n\x15ListLocationsResponse\x12\x30\n\tlocations\x18\x01 \x03(\x0b\x32\x1d.yandex.cloud.ydb.v1.Location\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x83\x02\n\x0fLocationService\x12v\n\x03Get\x12\'.yandex.cloud.ydb.v1.GetLocationRequest\x1a\x1d.yandex.cloud.ydb.v1.Location\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/ydb/v1/locations/{location_id}\x12x\n\x04List\x12).yandex.cloud.ydb.v1.ListLocationsRequest\x1a*.yandex.cloud.ydb.v1.ListLocationsResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/ydb/v1/locationsBV\n\x17yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydbb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_ydb_dot_v1_dot_location__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETLOCATIONREQUEST = _descriptor.Descriptor(
  name='GetLocationRequest',
  full_name='yandex.cloud.ydb.v1.GetLocationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='location_id', full_name='yandex.cloud.ydb.v1.GetLocationRequest.location_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=164,
  serialized_end=211,
)


_LISTLOCATIONSREQUEST = _descriptor.Descriptor(
  name='ListLocationsRequest',
  full_name='yandex.cloud.ydb.v1.ListLocationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.ydb.v1.ListLocationsRequest.page_size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.ydb.v1.ListLocationsRequest.page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=213,
  serialized_end=297,
)


_LISTLOCATIONSRESPONSE = _descriptor.Descriptor(
  name='ListLocationsResponse',
  full_name='yandex.cloud.ydb.v1.ListLocationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locations', full_name='yandex.cloud.ydb.v1.ListLocationsResponse.locations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.ydb.v1.ListLocationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=397,
)

_LISTLOCATIONSRESPONSE.fields_by_name['locations'].message_type = yandex_dot_cloud_dot_ydb_dot_v1_dot_location__pb2._LOCATION
DESCRIPTOR.message_types_by_name['GetLocationRequest'] = _GETLOCATIONREQUEST
DESCRIPTOR.message_types_by_name['ListLocationsRequest'] = _LISTLOCATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListLocationsResponse'] = _LISTLOCATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetLocationRequest = _reflection.GeneratedProtocolMessageType('GetLocationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLOCATIONREQUEST,
  '__module__' : 'yandex.cloud.ydb.v1.location_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.GetLocationRequest)
  })
_sym_db.RegisterMessage(GetLocationRequest)

ListLocationsRequest = _reflection.GeneratedProtocolMessageType('ListLocationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLOCATIONSREQUEST,
  '__module__' : 'yandex.cloud.ydb.v1.location_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.ListLocationsRequest)
  })
_sym_db.RegisterMessage(ListLocationsRequest)

ListLocationsResponse = _reflection.GeneratedProtocolMessageType('ListLocationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLOCATIONSRESPONSE,
  '__module__' : 'yandex.cloud.ydb.v1.location_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.ListLocationsResponse)
  })
_sym_db.RegisterMessage(ListLocationsResponse)


DESCRIPTOR._options = None
_GETLOCATIONREQUEST.fields_by_name['location_id']._options = None
_LISTLOCATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTLOCATIONSREQUEST.fields_by_name['page_token']._options = None

_LOCATIONSERVICE = _descriptor.ServiceDescriptor(
  name='LocationService',
  full_name='yandex.cloud.ydb.v1.LocationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=400,
  serialized_end=659,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.ydb.v1.LocationService.Get',
    index=0,
    containing_service=None,
    input_type=_GETLOCATIONREQUEST,
    output_type=yandex_dot_cloud_dot_ydb_dot_v1_dot_location__pb2._LOCATION,
    serialized_options=b'\202\323\344\223\002!\022\037/ydb/v1/locations/{location_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.ydb.v1.LocationService.List',
    index=1,
    containing_service=None,
    input_type=_LISTLOCATIONSREQUEST,
    output_type=_LISTLOCATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\022\021/ydb/v1/locations',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LOCATIONSERVICE)

DESCRIPTOR.services_by_name['LocationService'] = _LOCATIONSERVICE

# @@protoc_insertion_point(module_scope)



from setuptools import find_packages, setup

packages = find_packages(".", include=["yandexcloud*", "yandex*"])

__version__ = "0.221.0"

setup(
    name="yandexcloud",
    version=__version__,
    description="The Yandex.Cloud official SDK",
    url="https://github.com/yandex-cloud/python-sdk",
    author="Yandex LLC",
    author_email="cloud@support.yandex.ru",
    license="MIT",
    install_requires=[
        "cryptography>=2.8",
        "grpcio>=1.38.1",
        "protobuf<3.21",
        "googleapis-common-protos>=1.53.0",
        "pyjwt>=1.7.1",
        "requests>=2.22.0",
        "six>=1.14.0",
    ],
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
    tests_require=["pytest"],
    packages=packages,
    zip_safe=False,
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/stt/v3/stt.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/ai/stt/v3/stt.proto',
  package='speechkit.stt.v3',
  syntax='proto3',
  serialized_options=b'\n\032yandex.cloud.api.ai.stt.v3Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/stt/v3;stt',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n yandex/cloud/ai/stt/v3/stt.proto\x12\x10speechkit.stt.v3\"\xe2\x03\n\x18TextNormalizationOptions\x12X\n\x12text_normalization\x18\x01 \x01(\x0e\x32<.speechkit.stt.v3.TextNormalizationOptions.TextNormalization\x12\x18\n\x10profanity_filter\x18\x02 \x01(\x08\x12\x17\n\x0fliterature_text\x18\x03 \x01(\x08\x12]\n\x15phone_formatting_mode\x18\x04 \x01(\x0e\x32>.speechkit.stt.v3.TextNormalizationOptions.PhoneFormattingMode\"x\n\x11TextNormalization\x12\"\n\x1eTEXT_NORMALIZATION_UNSPECIFIED\x10\x00\x12\x1e\n\x1aTEXT_NORMALIZATION_ENABLED\x10\x01\x12\x1f\n\x1bTEXT_NORMALIZATION_DISABLED\x10\x02\"`\n\x13PhoneFormattingMode\x12%\n!PHONE_FORMATTING_MODE_UNSPECIFIED\x10\x00\x12\"\n\x1ePHONE_FORMATTING_MODE_DISABLED\x10\x01\"\xce\x01\n\x14\x44\x65\x66\x61ultEouClassifier\x12\x43\n\x04type\x18\x01 \x01(\x0e\x32\x35.speechkit.stt.v3.DefaultEouClassifier.EouSensitivity\x12\'\n\x1fmax_pause_between_words_hint_ms\x18\x02 \x01(\x03\"H\n\x0e\x45ouSensitivity\x12\x1f\n\x1b\x45OU_SENSITIVITY_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x01\x12\x08\n\x04HIGH\x10\x02\"\x17\n\x15\x45xternalEouClassifier\"\xb2\x01\n\x14\x45ouClassifierOptions\x12\x44\n\x12\x64\x65\x66\x61ult_classifier\x18\x01 \x01(\x0b\x32&.speechkit.stt.v3.DefaultEouClassifierH\x00\x12\x46\n\x13\x65xternal_classifier\x18\x02 \x01(\x0b\x32\'.speechkit.stt.v3.ExternalEouClassifierH\x00\x42\x0c\n\nClassifier\"\xc7\x01\n\x08RawAudio\x12@\n\x0e\x61udio_encoding\x18\x01 \x01(\x0e\x32(.speechkit.stt.v3.RawAudio.AudioEncoding\x12\x19\n\x11sample_rate_hertz\x18\x02 \x01(\x03\x12\x1b\n\x13\x61udio_channel_count\x18\x03 \x01(\x03\"A\n\rAudioEncoding\x12\x1e\n\x1a\x41UDIO_ENCODING_UNSPECIFIED\x10\x00\x12\x10\n\x0cLINEAR16_PCM\x10\x01\"\xbf\x01\n\x0e\x43ontainerAudio\x12Q\n\x14\x63ontainer_audio_type\x18\x01 \x01(\x0e\x32\x33.speechkit.stt.v3.ContainerAudio.ContainerAudioType\"Z\n\x12\x43ontainerAudioType\x12$\n CONTAINER_AUDIO_TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03WAV\x10\x01\x12\x0c\n\x08OGG_OPUS\x10\x02\x12\x07\n\x03MP3\x10\x03\"\x91\x01\n\x12\x41udioFormatOptions\x12/\n\traw_audio\x18\x01 \x01(\x0b\x32\x1a.speechkit.stt.v3.RawAudioH\x00\x12;\n\x0f\x63ontainer_audio\x18\x02 \x01(\x0b\x32 .speechkit.stt.v3.ContainerAudioH\x00\x42\r\n\x0b\x41udioFormat\"\xf7\x01\n\x1aLanguageRestrictionOptions\x12^\n\x10restriction_type\x18\x01 \x01(\x0e\x32\x44.speechkit.stt.v3.LanguageRestrictionOptions.LanguageRestrictionType\x12\x15\n\rlanguage_code\x18\x02 \x03(\t\"b\n\x17LanguageRestrictionType\x12)\n%LANGUAGE_RESTRICTION_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tWHITELIST\x10\x01\x12\r\n\tBLACKLIST\x10\x02\"\xb2\x03\n\x17RecognitionModelOptions\x12\r\n\x05model\x18\x01 \x01(\t\x12:\n\x0c\x61udio_format\x18\x02 \x01(\x0b\x32$.speechkit.stt.v3.AudioFormatOptions\x12\x46\n\x12text_normalization\x18\x03 \x01(\x0b\x32*.speechkit.stt.v3.TextNormalizationOptions\x12J\n\x14language_restriction\x18\x04 \x01(\x0b\x32,.speechkit.stt.v3.LanguageRestrictionOptions\x12\\\n\x15\x61udio_processing_type\x18\x05 \x01(\x0e\x32=.speechkit.stt.v3.RecognitionModelOptions.AudioProcessingType\"Z\n\x13\x41udioProcessingType\x12%\n!AUDIO_PROCESSING_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tREAL_TIME\x10\x01\x12\r\n\tFULL_DATA\x10\x02\"\x98\x01\n\x10StreamingOptions\x12\x44\n\x11recognition_model\x18\x01 \x01(\x0b\x32).speechkit.stt.v3.RecognitionModelOptions\x12>\n\x0e\x65ou_classifier\x18\x02 \x01(\x0b\x32&.speechkit.stt.v3.EouClassifierOptions\"\x1a\n\nAudioChunk\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"#\n\x0cSilenceChunk\x12\x13\n\x0b\x64uration_ms\x18\x01 \x01(\x03\"\x05\n\x03\x45ou\"\xe8\x01\n\x10StreamingRequest\x12=\n\x0fsession_options\x18\x01 \x01(\x0b\x32\".speechkit.stt.v3.StreamingOptionsH\x00\x12-\n\x05\x63hunk\x18\x02 \x01(\x0b\x32\x1c.speechkit.stt.v3.AudioChunkH\x00\x12\x37\n\rsilence_chunk\x18\x03 \x01(\x0b\x32\x1e.speechkit.stt.v3.SilenceChunkH\x00\x12$\n\x03\x65ou\x18\x04 \x01(\x0b\x32\x15.speechkit.stt.v3.EouH\x00\x42\x07\n\x05\x45vent\"@\n\x04Word\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x15\n\rstart_time_ms\x18\x02 \x01(\x03\x12\x13\n\x0b\x65nd_time_ms\x18\x03 \x01(\x03\"@\n\x12LanguageEstimation\x12\x15\n\rlanguage_code\x18\x01 \x01(\t\x12\x13\n\x0bprobability\x18\x02 \x01(\x01\"\xbb\x01\n\x0b\x41lternative\x12%\n\x05words\x18\x01 \x03(\x0b\x32\x16.speechkit.stt.v3.Word\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x15\n\rstart_time_ms\x18\x03 \x01(\x03\x12\x13\n\x0b\x65nd_time_ms\x18\x04 \x01(\x03\x12\x12\n\nconfidence\x18\x05 \x01(\x01\x12\x37\n\tlanguages\x18\x06 \x03(\x0b\x32$.speechkit.stt.v3.LanguageEstimation\"\x1c\n\tEouUpdate\x12\x0f\n\x07time_ms\x18\x02 \x01(\x03\"a\n\x11\x41lternativeUpdate\x12\x33\n\x0c\x61lternatives\x18\x01 \x03(\x0b\x32\x1d.speechkit.stt.v3.Alternative\x12\x17\n\x0b\x63hannel_tag\x18\x02 \x01(\tB\x02\x18\x01\"\x99\x01\n\x0c\x41udioCursors\x12\x18\n\x10received_data_ms\x18\x01 \x01(\x03\x12\x15\n\rreset_time_ms\x18\x02 \x01(\x03\x12\x17\n\x0fpartial_time_ms\x18\x03 \x01(\x03\x12\x15\n\rfinal_time_ms\x18\x04 \x01(\x03\x12\x13\n\x0b\x66inal_index\x18\x05 \x01(\x03\x12\x13\n\x0b\x65ou_time_ms\x18\x06 \x01(\x03\"n\n\x0f\x46inalRefinement\x12\x13\n\x0b\x66inal_index\x18\x01 \x01(\x03\x12>\n\x0fnormalized_text\x18\x02 \x01(\x0b\x32#.speechkit.stt.v3.AlternativeUpdateH\x00\x42\x06\n\x04Type\"L\n\nStatusCode\x12-\n\tcode_type\x18\x01 \x01(\x0e\x32\x1a.speechkit.stt.v3.CodeType\x12\x0f\n\x07message\x18\x02 \x01(\t\"4\n\x0bSessionUuid\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x17\n\x0fuser_request_id\x18\x02 \x01(\t\"\xd1\x03\n\x11StreamingResponse\x12\x33\n\x0csession_uuid\x18\x01 \x01(\x0b\x32\x1d.speechkit.stt.v3.SessionUuid\x12\x35\n\raudio_cursors\x18\x02 \x01(\x0b\x32\x1e.speechkit.stt.v3.AudioCursors\x12\x1d\n\x15response_wall_time_ms\x18\x03 \x01(\x03\x12\x36\n\x07partial\x18\x04 \x01(\x0b\x32#.speechkit.stt.v3.AlternativeUpdateH\x00\x12\x34\n\x05\x66inal\x18\x05 \x01(\x0b\x32#.speechkit.stt.v3.AlternativeUpdateH\x00\x12\x31\n\neou_update\x18\x06 \x01(\x0b\x32\x1b.speechkit.stt.v3.EouUpdateH\x00\x12=\n\x10\x66inal_refinement\x18\x07 \x01(\x0b\x32!.speechkit.stt.v3.FinalRefinementH\x00\x12\x33\n\x0bstatus_code\x18\x08 \x01(\x0b\x32\x1c.speechkit.stt.v3.StatusCodeH\x00\x12\x13\n\x0b\x63hannel_tag\x18\t \x01(\tB\x07\n\x05\x45vent*K\n\x08\x43odeType\x12\x19\n\x15\x43ODE_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07WORKING\x10\x01\x12\x0b\n\x07WARNING\x10\x02\x12\n\n\x06\x43LOSED\x10\x03\x42\\\n\x1ayandex.cloud.api.ai.stt.v3Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/stt/v3;sttb\x06proto3'
)

_CODETYPE = _descriptor.EnumDescriptor(
  name='CodeType',
  full_name='speechkit.stt.v3.CodeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CODE_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WORKING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLOSED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3966,
  serialized_end=4041,
)
_sym_db.RegisterEnumDescriptor(_CODETYPE)

CodeType = enum_type_wrapper.EnumTypeWrapper(_CODETYPE)
CODE_TYPE_UNSPECIFIED = 0
WORKING = 1
WARNING = 2
CLOSED = 3


_TEXTNORMALIZATIONOPTIONS_TEXTNORMALIZATION = _descriptor.EnumDescriptor(
  name='TextNormalization',
  full_name='speechkit.stt.v3.TextNormalizationOptions.TextNormalization',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TEXT_NORMALIZATION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEXT_NORMALIZATION_ENABLED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEXT_NORMALIZATION_DISABLED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=319,
  serialized_end=439,
)
_sym_db.RegisterEnumDescriptor(_TEXTNORMALIZATIONOPTIONS_TEXTNORMALIZATION)

_TEXTNORMALIZATIONOPTIONS_PHONEFORMATTINGMODE = _descriptor.EnumDescriptor(
  name='PhoneFormattingMode',
  full_name='speechkit.stt.v3.TextNormalizationOptions.PhoneFormattingMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PHONE_FORMATTING_MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PHONE_FORMATTING_MODE_DISABLED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=441,
  serialized_end=537,
)
_sym_db.RegisterEnumDescriptor(_TEXTNORMALIZATIONOPTIONS_PHONEFORMATTINGMODE)

_DEFAULTEOUCLASSIFIER_EOUSENSITIVITY = _descriptor.EnumDescriptor(
  name='EouSensitivity',
  full_name='speechkit.stt.v3.DefaultEouClassifier.EouSensitivity',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EOU_SENSITIVITY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGH', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=674,
  serialized_end=746,
)
_sym_db.RegisterEnumDescriptor(_DEFAULTEOUCLASSIFIER_EOUSENSITIVITY)

_RAWAUDIO_AUDIOENCODING = _descriptor.EnumDescriptor(
  name='AudioEncoding',
  full_name='speechkit.stt.v3.RawAudio.AudioEncoding',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUDIO_ENCODING_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LINEAR16_PCM', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1089,
  serialized_end=1154,
)
_sym_db.RegisterEnumDescriptor(_RAWAUDIO_AUDIOENCODING)

_CONTAINERAUDIO_CONTAINERAUDIOTYPE = _descriptor.EnumDescriptor(
  name='ContainerAudioType',
  full_name='speechkit.stt.v3.ContainerAudio.ContainerAudioType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONTAINER_AUDIO_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WAV', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OGG_OPUS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MP3', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1258,
  serialized_end=1348,
)
_sym_db.RegisterEnumDescriptor(_CONTAINERAUDIO_CONTAINERAUDIOTYPE)

_LANGUAGERESTRICTIONOPTIONS_LANGUAGERESTRICTIONTYPE = _descriptor.EnumDescriptor(
  name='LanguageRestrictionType',
  full_name='speechkit.stt.v3.LanguageRestrictionOptions.LanguageRestrictionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LANGUAGE_RESTRICTION_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WHITELIST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLACKLIST', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1648,
  serialized_end=1746,
)
_sym_db.RegisterEnumDescriptor(_LANGUAGERESTRICTIONOPTIONS_LANGUAGERESTRICTIONTYPE)

_RECOGNITIONMODELOPTIONS_AUDIOPROCESSINGTYPE = _descriptor.EnumDescriptor(
  name='AudioProcessingType',
  full_name='speechkit.stt.v3.RecognitionModelOptions.AudioProcessingType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUDIO_PROCESSING_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REAL_TIME', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FULL_DATA', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2093,
  serialized_end=2183,
)
_sym_db.RegisterEnumDescriptor(_RECOGNITIONMODELOPTIONS_AUDIOPROCESSINGTYPE)


_TEXTNORMALIZATIONOPTIONS = _descriptor.Descriptor(
  name='TextNormalizationOptions',
  full_name='speechkit.stt.v3.TextNormalizationOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text_normalization', full_name='speechkit.stt.v3.TextNormalizationOptions.text_normalization', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profanity_filter', full_name='speechkit.stt.v3.TextNormalizationOptions.profanity_filter', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='literature_text', full_name='speechkit.stt.v3.TextNormalizationOptions.literature_text', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phone_formatting_mode', full_name='speechkit.stt.v3.TextNormalizationOptions.phone_formatting_mode', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TEXTNORMALIZATIONOPTIONS_TEXTNORMALIZATION,
    _TEXTNORMALIZATIONOPTIONS_PHONEFORMATTINGMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=537,
)


_DEFAULTEOUCLASSIFIER = _descriptor.Descriptor(
  name='DefaultEouClassifier',
  full_name='speechkit.stt.v3.DefaultEouClassifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='speechkit.stt.v3.DefaultEouClassifier.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_pause_between_words_hint_ms', full_name='speechkit.stt.v3.DefaultEouClassifier.max_pause_between_words_hint_ms', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DEFAULTEOUCLASSIFIER_EOUSENSITIVITY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=540,
  serialized_end=746,
)


_EXTERNALEOUCLASSIFIER = _descriptor.Descriptor(
  name='ExternalEouClassifier',
  full_name='speechkit.stt.v3.ExternalEouClassifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=748,
  serialized_end=771,
)


_EOUCLASSIFIEROPTIONS = _descriptor.Descriptor(
  name='EouClassifierOptions',
  full_name='speechkit.stt.v3.EouClassifierOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_classifier', full_name='speechkit.stt.v3.EouClassifierOptions.default_classifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_classifier', full_name='speechkit.stt.v3.EouClassifierOptions.external_classifier', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Classifier', full_name='speechkit.stt.v3.EouClassifierOptions.Classifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=774,
  serialized_end=952,
)


_RAWAUDIO = _descriptor.Descriptor(
  name='RawAudio',
  full_name='speechkit.stt.v3.RawAudio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio_encoding', full_name='speechkit.stt.v3.RawAudio.audio_encoding', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sample_rate_hertz', full_name='speechkit.stt.v3.RawAudio.sample_rate_hertz', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audio_channel_count', full_name='speechkit.stt.v3.RawAudio.audio_channel_count', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RAWAUDIO_AUDIOENCODING,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=955,
  serialized_end=1154,
)


_CONTAINERAUDIO = _descriptor.Descriptor(
  name='ContainerAudio',
  full_name='speechkit.stt.v3.ContainerAudio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_audio_type', full_name='speechkit.stt.v3.ContainerAudio.container_audio_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONTAINERAUDIO_CONTAINERAUDIOTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1157,
  serialized_end=1348,
)


_AUDIOFORMATOPTIONS = _descriptor.Descriptor(
  name='AudioFormatOptions',
  full_name='speechkit.stt.v3.AudioFormatOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw_audio', full_name='speechkit.stt.v3.AudioFormatOptions.raw_audio', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='container_audio', full_name='speechkit.stt.v3.AudioFormatOptions.container_audio', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='AudioFormat', full_name='speechkit.stt.v3.AudioFormatOptions.AudioFormat',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1351,
  serialized_end=1496,
)


_LANGUAGERESTRICTIONOPTIONS = _descriptor.Descriptor(
  name='LanguageRestrictionOptions',
  full_name='speechkit.stt.v3.LanguageRestrictionOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='restriction_type', full_name='speechkit.stt.v3.LanguageRestrictionOptions.restriction_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language_code', full_name='speechkit.stt.v3.LanguageRestrictionOptions.language_code', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LANGUAGERESTRICTIONOPTIONS_LANGUAGERESTRICTIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1499,
  serialized_end=1746,
)


_RECOGNITIONMODELOPTIONS = _descriptor.Descriptor(
  name='RecognitionModelOptions',
  full_name='speechkit.stt.v3.RecognitionModelOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model', full_name='speechkit.stt.v3.RecognitionModelOptions.model', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audio_format', full_name='speechkit.stt.v3.RecognitionModelOptions.audio_format', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_normalization', full_name='speechkit.stt.v3.RecognitionModelOptions.text_normalization', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language_restriction', full_name='speechkit.stt.v3.RecognitionModelOptions.language_restriction', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audio_processing_type', full_name='speechkit.stt.v3.RecognitionModelOptions.audio_processing_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RECOGNITIONMODELOPTIONS_AUDIOPROCESSINGTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1749,
  serialized_end=2183,
)


_STREAMINGOPTIONS = _descriptor.Descriptor(
  name='StreamingOptions',
  full_name='speechkit.stt.v3.StreamingOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='recognition_model', full_name='speechkit.stt.v3.StreamingOptions.recognition_model', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eou_classifier', full_name='speechkit.stt.v3.StreamingOptions.eou_classifier', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2186,
  serialized_end=2338,
)


_AUDIOCHUNK = _descriptor.Descriptor(
  name='AudioChunk',
  full_name='speechkit.stt.v3.AudioChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='speechkit.stt.v3.AudioChunk.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2340,
  serialized_end=2366,
)


_SILENCECHUNK = _descriptor.Descriptor(
  name='SilenceChunk',
  full_name='speechkit.stt.v3.SilenceChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='duration_ms', full_name='speechkit.stt.v3.SilenceChunk.duration_ms', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2368,
  serialized_end=2403,
)


_EOU = _descriptor.Descriptor(
  name='Eou',
  full_name='speechkit.stt.v3.Eou',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2405,
  serialized_end=2410,
)


_STREAMINGREQUEST = _descriptor.Descriptor(
  name='StreamingRequest',
  full_name='speechkit.stt.v3.StreamingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_options', full_name='speechkit.stt.v3.StreamingRequest.session_options', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chunk', full_name='speechkit.stt.v3.StreamingRequest.chunk', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='silence_chunk', full_name='speechkit.stt.v3.StreamingRequest.silence_chunk', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eou', full_name='speechkit.stt.v3.StreamingRequest.eou', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Event', full_name='speechkit.stt.v3.StreamingRequest.Event',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2413,
  serialized_end=2645,
)


_WORD = _descriptor.Descriptor(
  name='Word',
  full_name='speechkit.stt.v3.Word',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='speechkit.stt.v3.Word.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time_ms', full_name='speechkit.stt.v3.Word.start_time_ms', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time_ms', full_name='speechkit.stt.v3.Word.end_time_ms', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2647,
  serialized_end=2711,
)


_LANGUAGEESTIMATION = _descriptor.Descriptor(
  name='LanguageEstimation',
  full_name='speechkit.stt.v3.LanguageEstimation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='language_code', full_name='speechkit.stt.v3.LanguageEstimation.language_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='probability', full_name='speechkit.stt.v3.LanguageEstimation.probability', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2713,
  serialized_end=2777,
)


_ALTERNATIVE = _descriptor.Descriptor(
  name='Alternative',
  full_name='speechkit.stt.v3.Alternative',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='words', full_name='speechkit.stt.v3.Alternative.words', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='speechkit.stt.v3.Alternative.text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time_ms', full_name='speechkit.stt.v3.Alternative.start_time_ms', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time_ms', full_name='speechkit.stt.v3.Alternative.end_time_ms', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='speechkit.stt.v3.Alternative.confidence', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='languages', full_name='speechkit.stt.v3.Alternative.languages', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2780,
  serialized_end=2967,
)


_EOUUPDATE = _descriptor.Descriptor(
  name='EouUpdate',
  full_name='speechkit.stt.v3.EouUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_ms', full_name='speechkit.stt.v3.EouUpdate.time_ms', index=0,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2969,
  serialized_end=2997,
)


_ALTERNATIVEUPDATE = _descriptor.Descriptor(
  name='AlternativeUpdate',
  full_name='speechkit.stt.v3.AlternativeUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='alternatives', full_name='speechkit.stt.v3.AlternativeUpdate.alternatives', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_tag', full_name='speechkit.stt.v3.AlternativeUpdate.channel_tag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2999,
  serialized_end=3096,
)


_AUDIOCURSORS = _descriptor.Descriptor(
  name='AudioCursors',
  full_name='speechkit.stt.v3.AudioCursors',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='received_data_ms', full_name='speechkit.stt.v3.AudioCursors.received_data_ms', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reset_time_ms', full_name='speechkit.stt.v3.AudioCursors.reset_time_ms', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partial_time_ms', full_name='speechkit.stt.v3.AudioCursors.partial_time_ms', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='final_time_ms', full_name='speechkit.stt.v3.AudioCursors.final_time_ms', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='final_index', full_name='speechkit.stt.v3.AudioCursors.final_index', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eou_time_ms', full_name='speechkit.stt.v3.AudioCursors.eou_time_ms', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3099,
  serialized_end=3252,
)


_FINALREFINEMENT = _descriptor.Descriptor(
  name='FinalRefinement',
  full_name='speechkit.stt.v3.FinalRefinement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='final_index', full_name='speechkit.stt.v3.FinalRefinement.final_index', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='normalized_text', full_name='speechkit.stt.v3.FinalRefinement.normalized_text', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Type', full_name='speechkit.stt.v3.FinalRefinement.Type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3254,
  serialized_end=3364,
)


_STATUSCODE = _descriptor.Descriptor(
  name='StatusCode',
  full_name='speechkit.stt.v3.StatusCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code_type', full_name='speechkit.stt.v3.StatusCode.code_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='speechkit.stt.v3.StatusCode.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3366,
  serialized_end=3442,
)


_SESSIONUUID = _descriptor.Descriptor(
  name='SessionUuid',
  full_name='speechkit.stt.v3.SessionUuid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='speechkit.stt.v3.SessionUuid.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_request_id', full_name='speechkit.stt.v3.SessionUuid.user_request_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3444,
  serialized_end=3496,
)


_STREAMINGRESPONSE = _descriptor.Descriptor(
  name='StreamingResponse',
  full_name='speechkit.stt.v3.StreamingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_uuid', full_name='speechkit.stt.v3.StreamingResponse.session_uuid', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audio_cursors', full_name='speechkit.stt.v3.StreamingResponse.audio_cursors', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_wall_time_ms', full_name='speechkit.stt.v3.StreamingResponse.response_wall_time_ms', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partial', full_name='speechkit.stt.v3.StreamingResponse.partial', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='final', full_name='speechkit.stt.v3.StreamingResponse.final', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eou_update', full_name='speechkit.stt.v3.StreamingResponse.eou_update', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='final_refinement', full_name='speechkit.stt.v3.StreamingResponse.final_refinement', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code', full_name='speechkit.stt.v3.StreamingResponse.status_code', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_tag', full_name='speechkit.stt.v3.StreamingResponse.channel_tag', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Event', full_name='speechkit.stt.v3.StreamingResponse.Event',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3499,
  serialized_end=3964,
)

_TEXTNORMALIZATIONOPTIONS.fields_by_name['text_normalization'].enum_type = _TEXTNORMALIZATIONOPTIONS_TEXTNORMALIZATION
_TEXTNORMALIZATIONOPTIONS.fields_by_name['phone_formatting_mode'].enum_type = _TEXTNORMALIZATIONOPTIONS_PHONEFORMATTINGMODE
_TEXTNORMALIZATIONOPTIONS_TEXTNORMALIZATION.containing_type = _TEXTNORMALIZATIONOPTIONS
_TEXTNORMALIZATIONOPTIONS_PHONEFORMATTINGMODE.containing_type = _TEXTNORMALIZATIONOPTIONS
_DEFAULTEOUCLASSIFIER.fields_by_name['type'].enum_type = _DEFAULTEOUCLASSIFIER_EOUSENSITIVITY
_DEFAULTEOUCLASSIFIER_EOUSENSITIVITY.containing_type = _DEFAULTEOUCLASSIFIER
_EOUCLASSIFIEROPTIONS.fields_by_name['default_classifier'].message_type = _DEFAULTEOUCLASSIFIER
_EOUCLASSIFIEROPTIONS.fields_by_name['external_classifier'].message_type = _EXTERNALEOUCLASSIFIER
_EOUCLASSIFIEROPTIONS.oneofs_by_name['Classifier'].fields.append(
  _EOUCLASSIFIEROPTIONS.fields_by_name['default_classifier'])
_EOUCLASSIFIEROPTIONS.fields_by_name['default_classifier'].containing_oneof = _EOUCLASSIFIEROPTIONS.oneofs_by_name['Classifier']
_EOUCLASSIFIEROPTIONS.oneofs_by_name['Classifier'].fields.append(
  _EOUCLASSIFIEROPTIONS.fields_by_name['external_classifier'])
_EOUCLASSIFIEROPTIONS.fields_by_name['external_classifier'].containing_oneof = _EOUCLASSIFIEROPTIONS.oneofs_by_name['Classifier']
_RAWAUDIO.fields_by_name['audio_encoding'].enum_type = _RAWAUDIO_AUDIOENCODING
_RAWAUDIO_AUDIOENCODING.containing_type = _RAWAUDIO
_CONTAINERAUDIO.fields_by_name['container_audio_type'].enum_type = _CONTAINERAUDIO_CONTAINERAUDIOTYPE
_CONTAINERAUDIO_CONTAINERAUDIOTYPE.containing_type = _CONTAINERAUDIO
_AUDIOFORMATOPTIONS.fields_by_name['raw_audio'].message_type = _RAWAUDIO
_AUDIOFORMATOPTIONS.fields_by_name['container_audio'].message_type = _CONTAINERAUDIO
_AUDIOFORMATOPTIONS.oneofs_by_name['AudioFormat'].fields.append(
  _AUDIOFORMATOPTIONS.fields_by_name['raw_audio'])
_AUDIOFORMATOPTIONS.fields_by_name['raw_audio'].containing_oneof = _AUDIOFORMATOPTIONS.oneofs_by_name['AudioFormat']
_AUDIOFORMATOPTIONS.oneofs_by_name['AudioFormat'].fields.append(
  _AUDIOFORMATOPTIONS.fields_by_name['container_audio'])
_AUDIOFORMATOPTIONS.fields_by_name['container_audio'].containing_oneof = _AUDIOFORMATOPTIONS.oneofs_by_name['AudioFormat']
_LANGUAGERESTRICTIONOPTIONS.fields_by_name['restriction_type'].enum_type = _LANGUAGERESTRICTIONOPTIONS_LANGUAGERESTRICTIONTYPE
_LANGUAGERESTRICTIONOPTIONS_LANGUAGERESTRICTIONTYPE.containing_type = _LANGUAGERESTRICTIONOPTIONS
_RECOGNITIONMODELOPTIONS.fields_by_name['audio_format'].message_type = _AUDIOFORMATOPTIONS
_RECOGNITIONMODELOPTIONS.fields_by_name['text_normalization'].message_type = _TEXTNORMALIZATIONOPTIONS
_RECOGNITIONMODELOPTIONS.fields_by_name['language_restriction'].message_type = _LANGUAGERESTRICTIONOPTIONS
_RECOGNITIONMODELOPTIONS.fields_by_name['audio_processing_type'].enum_type = _RECOGNITIONMODELOPTIONS_AUDIOPROCESSINGTYPE
_RECOGNITIONMODELOPTIONS_AUDIOPROCESSINGTYPE.containing_type = _RECOGNITIONMODELOPTIONS
_STREAMINGOPTIONS.fields_by_name['recognition_model'].message_type = _RECOGNITIONMODELOPTIONS
_STREAMINGOPTIONS.fields_by_name['eou_classifier'].message_type = _EOUCLASSIFIEROPTIONS
_STREAMINGREQUEST.fields_by_name['session_options'].message_type = _STREAMINGOPTIONS
_STREAMINGREQUEST.fields_by_name['chunk'].message_type = _AUDIOCHUNK
_STREAMINGREQUEST.fields_by_name['silence_chunk'].message_type = _SILENCECHUNK
_STREAMINGREQUEST.fields_by_name['eou'].message_type = _EOU
_STREAMINGREQUEST.oneofs_by_name['Event'].fields.append(
  _STREAMINGREQUEST.fields_by_name['session_options'])
_STREAMINGREQUEST.fields_by_name['session_options'].containing_oneof = _STREAMINGREQUEST.oneofs_by_name['Event']
_STREAMINGREQUEST.oneofs_by_name['Event'].fields.append(
  _STREAMINGREQUEST.fields_by_name['chunk'])
_STREAMINGREQUEST.fields_by_name['chunk'].containing_oneof = _STREAMINGREQUEST.oneofs_by_name['Event']
_STREAMINGREQUEST.oneofs_by_name['Event'].fields.append(
  _STREAMINGREQUEST.fields_by_name['silence_chunk'])
_STREAMINGREQUEST.fields_by_name['silence_chunk'].containing_oneof = _STREAMINGREQUEST.oneofs_by_name['Event']
_STREAMINGREQUEST.oneofs_by_name['Event'].fields.append(
  _STREAMINGREQUEST.fields_by_name['eou'])
_STREAMINGREQUEST.fields_by_name['eou'].containing_oneof = _STREAMINGREQUEST.oneofs_by_name['Event']
_ALTERNATIVE.fields_by_name['words'].message_type = _WORD
_ALTERNATIVE.fields_by_name['languages'].message_type = _LANGUAGEESTIMATION
_ALTERNATIVEUPDATE.fields_by_name['alternatives'].message_type = _ALTERNATIVE
_FINALREFINEMENT.fields_by_name['normalized_text'].message_type = _ALTERNATIVEUPDATE
_FINALREFINEMENT.oneofs_by_name['Type'].fields.append(
  _FINALREFINEMENT.fields_by_name['normalized_text'])
_FINALREFINEMENT.fields_by_name['normalized_text'].containing_oneof = _FINALREFINEMENT.oneofs_by_name['Type']
_STATUSCODE.fields_by_name['code_type'].enum_type = _CODETYPE
_STREAMINGRESPONSE.fields_by_name['session_uuid'].message_type = _SESSIONUUID
_STREAMINGRESPONSE.fields_by_name['audio_cursors'].message_type = _AUDIOCURSORS
_STREAMINGRESPONSE.fields_by_name['partial'].message_type = _ALTERNATIVEUPDATE
_STREAMINGRESPONSE.fields_by_name['final'].message_type = _ALTERNATIVEUPDATE
_STREAMINGRESPONSE.fields_by_name['eou_update'].message_type = _EOUUPDATE
_STREAMINGRESPONSE.fields_by_name['final_refinement'].message_type = _FINALREFINEMENT
_STREAMINGRESPONSE.fields_by_name['status_code'].message_type = _STATUSCODE
_STREAMINGRESPONSE.oneofs_by_name['Event'].fields.append(
  _STREAMINGRESPONSE.fields_by_name['partial'])
_STREAMINGRESPONSE.fields_by_name['partial'].containing_oneof = _STREAMINGRESPONSE.oneofs_by_name['Event']
_STREAMINGRESPONSE.oneofs_by_name['Event'].fields.append(
  _STREAMINGRESPONSE.fields_by_name['final'])
_STREAMINGRESPONSE.fields_by_name['final'].containing_oneof = _STREAMINGRESPONSE.oneofs_by_name['Event']
_STREAMINGRESPONSE.oneofs_by_name['Event'].fields.append(
  _STREAMINGRESPONSE.fields_by_name['eou_update'])
_STREAMINGRESPONSE.fields_by_name['eou_update'].containing_oneof = _STREAMINGRESPONSE.oneofs_by_name['Event']
_STREAMINGRESPONSE.oneofs_by_name['Event'].fields.append(
  _STREAMINGRESPONSE.fields_by_name['final_refinement'])
_STREAMINGRESPONSE.fields_by_name['final_refinement'].containing_oneof = _STREAMINGRESPONSE.oneofs_by_name['Event']
_STREAMINGRESPONSE.oneofs_by_name['Event'].fields.append(
  _STREAMINGRESPONSE.fields_by_name['status_code'])
_STREAMINGRESPONSE.fields_by_name['status_code'].containing_oneof = _STREAMINGRESPONSE.oneofs_by_name['Event']
DESCRIPTOR.message_types_by_name['TextNormalizationOptions'] = _TEXTNORMALIZATIONOPTIONS
DESCRIPTOR.message_types_by_name['DefaultEouClassifier'] = _DEFAULTEOUCLASSIFIER
DESCRIPTOR.message_types_by_name['ExternalEouClassifier'] = _EXTERNALEOUCLASSIFIER
DESCRIPTOR.message_types_by_name['EouClassifierOptions'] = _EOUCLASSIFIEROPTIONS
DESCRIPTOR.message_types_by_name['RawAudio'] = _RAWAUDIO
DESCRIPTOR.message_types_by_name['ContainerAudio'] = _CONTAINERAUDIO
DESCRIPTOR.message_types_by_name['AudioFormatOptions'] = _AUDIOFORMATOPTIONS
DESCRIPTOR.message_types_by_name['LanguageRestrictionOptions'] = _LANGUAGERESTRICTIONOPTIONS
DESCRIPTOR.message_types_by_name['RecognitionModelOptions'] = _RECOGNITIONMODELOPTIONS
DESCRIPTOR.message_types_by_name['StreamingOptions'] = _STREAMINGOPTIONS
DESCRIPTOR.message_types_by_name['AudioChunk'] = _AUDIOCHUNK
DESCRIPTOR.message_types_by_name['SilenceChunk'] = _SILENCECHUNK
DESCRIPTOR.message_types_by_name['Eou'] = _EOU
DESCRIPTOR.message_types_by_name['StreamingRequest'] = _STREAMINGREQUEST
DESCRIPTOR.message_types_by_name['Word'] = _WORD
DESCRIPTOR.message_types_by_name['LanguageEstimation'] = _LANGUAGEESTIMATION
DESCRIPTOR.message_types_by_name['Alternative'] = _ALTERNATIVE
DESCRIPTOR.message_types_by_name['EouUpdate'] = _EOUUPDATE
DESCRIPTOR.message_types_by_name['AlternativeUpdate'] = _ALTERNATIVEUPDATE
DESCRIPTOR.message_types_by_name['AudioCursors'] = _AUDIOCURSORS
DESCRIPTOR.message_types_by_name['FinalRefinement'] = _FINALREFINEMENT
DESCRIPTOR.message_types_by_name['StatusCode'] = _STATUSCODE
DESCRIPTOR.message_types_by_name['SessionUuid'] = _SESSIONUUID
DESCRIPTOR.message_types_by_name['StreamingResponse'] = _STREAMINGRESPONSE
DESCRIPTOR.enum_types_by_name['CodeType'] = _CODETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TextNormalizationOptions = _reflection.GeneratedProtocolMessageType('TextNormalizationOptions', (_message.Message,), {
  'DESCRIPTOR' : _TEXTNORMALIZATIONOPTIONS,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.TextNormalizationOptions)
  })
_sym_db.RegisterMessage(TextNormalizationOptions)

DefaultEouClassifier = _reflection.GeneratedProtocolMessageType('DefaultEouClassifier', (_message.Message,), {
  'DESCRIPTOR' : _DEFAULTEOUCLASSIFIER,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.DefaultEouClassifier)
  })
_sym_db.RegisterMessage(DefaultEouClassifier)

ExternalEouClassifier = _reflection.GeneratedProtocolMessageType('ExternalEouClassifier', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALEOUCLASSIFIER,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.ExternalEouClassifier)
  })
_sym_db.RegisterMessage(ExternalEouClassifier)

EouClassifierOptions = _reflection.GeneratedProtocolMessageType('EouClassifierOptions', (_message.Message,), {
  'DESCRIPTOR' : _EOUCLASSIFIEROPTIONS,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.EouClassifierOptions)
  })
_sym_db.RegisterMessage(EouClassifierOptions)

RawAudio = _reflection.GeneratedProtocolMessageType('RawAudio', (_message.Message,), {
  'DESCRIPTOR' : _RAWAUDIO,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.RawAudio)
  })
_sym_db.RegisterMessage(RawAudio)

ContainerAudio = _reflection.GeneratedProtocolMessageType('ContainerAudio', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINERAUDIO,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.ContainerAudio)
  })
_sym_db.RegisterMessage(ContainerAudio)

AudioFormatOptions = _reflection.GeneratedProtocolMessageType('AudioFormatOptions', (_message.Message,), {
  'DESCRIPTOR' : _AUDIOFORMATOPTIONS,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.AudioFormatOptions)
  })
_sym_db.RegisterMessage(AudioFormatOptions)

LanguageRestrictionOptions = _reflection.GeneratedProtocolMessageType('LanguageRestrictionOptions', (_message.Message,), {
  'DESCRIPTOR' : _LANGUAGERESTRICTIONOPTIONS,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.LanguageRestrictionOptions)
  })
_sym_db.RegisterMessage(LanguageRestrictionOptions)

RecognitionModelOptions = _reflection.GeneratedProtocolMessageType('RecognitionModelOptions', (_message.Message,), {
  'DESCRIPTOR' : _RECOGNITIONMODELOPTIONS,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.RecognitionModelOptions)
  })
_sym_db.RegisterMessage(RecognitionModelOptions)

StreamingOptions = _reflection.GeneratedProtocolMessageType('StreamingOptions', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGOPTIONS,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.StreamingOptions)
  })
_sym_db.RegisterMessage(StreamingOptions)

AudioChunk = _reflection.GeneratedProtocolMessageType('AudioChunk', (_message.Message,), {
  'DESCRIPTOR' : _AUDIOCHUNK,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.AudioChunk)
  })
_sym_db.RegisterMessage(AudioChunk)

SilenceChunk = _reflection.GeneratedProtocolMessageType('SilenceChunk', (_message.Message,), {
  'DESCRIPTOR' : _SILENCECHUNK,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.SilenceChunk)
  })
_sym_db.RegisterMessage(SilenceChunk)

Eou = _reflection.GeneratedProtocolMessageType('Eou', (_message.Message,), {
  'DESCRIPTOR' : _EOU,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.Eou)
  })
_sym_db.RegisterMessage(Eou)

StreamingRequest = _reflection.GeneratedProtocolMessageType('StreamingRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGREQUEST,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.StreamingRequest)
  })
_sym_db.RegisterMessage(StreamingRequest)

Word = _reflection.GeneratedProtocolMessageType('Word', (_message.Message,), {
  'DESCRIPTOR' : _WORD,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.Word)
  })
_sym_db.RegisterMessage(Word)

LanguageEstimation = _reflection.GeneratedProtocolMessageType('LanguageEstimation', (_message.Message,), {
  'DESCRIPTOR' : _LANGUAGEESTIMATION,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.LanguageEstimation)
  })
_sym_db.RegisterMessage(LanguageEstimation)

Alternative = _reflection.GeneratedProtocolMessageType('Alternative', (_message.Message,), {
  'DESCRIPTOR' : _ALTERNATIVE,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.Alternative)
  })
_sym_db.RegisterMessage(Alternative)

EouUpdate = _reflection.GeneratedProtocolMessageType('EouUpdate', (_message.Message,), {
  'DESCRIPTOR' : _EOUUPDATE,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.EouUpdate)
  })
_sym_db.RegisterMessage(EouUpdate)

AlternativeUpdate = _reflection.GeneratedProtocolMessageType('AlternativeUpdate', (_message.Message,), {
  'DESCRIPTOR' : _ALTERNATIVEUPDATE,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.AlternativeUpdate)
  })
_sym_db.RegisterMessage(AlternativeUpdate)

AudioCursors = _reflection.GeneratedProtocolMessageType('AudioCursors', (_message.Message,), {
  'DESCRIPTOR' : _AUDIOCURSORS,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.AudioCursors)
  })
_sym_db.RegisterMessage(AudioCursors)

FinalRefinement = _reflection.GeneratedProtocolMessageType('FinalRefinement', (_message.Message,), {
  'DESCRIPTOR' : _FINALREFINEMENT,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.FinalRefinement)
  })
_sym_db.RegisterMessage(FinalRefinement)

StatusCode = _reflection.GeneratedProtocolMessageType('StatusCode', (_message.Message,), {
  'DESCRIPTOR' : _STATUSCODE,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.StatusCode)
  })
_sym_db.RegisterMessage(StatusCode)

SessionUuid = _reflection.GeneratedProtocolMessageType('SessionUuid', (_message.Message,), {
  'DESCRIPTOR' : _SESSIONUUID,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.SessionUuid)
  })
_sym_db.RegisterMessage(SessionUuid)

StreamingResponse = _reflection.GeneratedProtocolMessageType('StreamingResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGRESPONSE,
  '__module__' : 'yandex.cloud.ai.stt.v3.stt_pb2'
  # @@protoc_insertion_point(class_scope:speechkit.stt.v3.StreamingResponse)
  })
_sym_db.RegisterMessage(StreamingResponse)


DESCRIPTOR._options = None
_ALTERNATIVEUPDATE.fields_by_name['channel_tag']._options = None
# @@protoc_insertion_point(module_scope)
